% Auto-generated chapter 13 for bukhari
% Hadiths in this chapter: 37

\hadithdefcmd{bukhari}{948}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ أَخَذَ عُمَرُ جُبَّةً مِنْ إِسْتَبْرَقٍ تُبَاعُ فِي السُّوقِ، فَأَخَذَهَا فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ ابْتَعْ هَذِهِ تَجَمَّلْ بِهَا لِلْعِيدِ وَالْوُفُودِ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ ‏"‏‏.‏ فَلَبِثَ عُمَرُ مَا شَاءَ اللَّهُ أَنْ يَلْبَثَ، ثُمَّ أَرْسَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِجُبَّةِ دِيبَاجٍ، فَأَقْبَلَ بِهَا عُمَرُ، فَأَتَى بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّكَ قُلْتَ ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ ‏"‏‏.‏ وَأَرْسَلْتَ إِلَىَّ بِهَذِهِ الْجُبَّةِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَبِيعُهَا أَوْ تُصِيبُ بِهَا حَاجَتَكَ ‏"‏‏.‏\hadithno{948}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bought a silk cloak from the market, took it to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Take it and adorn yourself with it during the `Id and when the delegations visit you." Allah's Messenger (ﷺ) replied, "This dress is for those who have no share (in the Hereafter)." After a long period Allah's Messenger (ﷺ) sent to `Umar a cloak of silk brocade. `Umar came to Allah's Messenger (ﷺ) with the cloak and said, "O Allah's Messenger (ﷺ)! You said that this dress was for those who had no share (in the Hereafter); yet you have sent me this cloak." Allah's Messenger (ﷺ) said to him, "Sell it and fulfill your needs by it}}
\hadithdefcmd{bukhari}{950}{حَدَّثَنَا أَحْمَدُ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنَا عَمْرٌو، أَنَّ مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ الأَسَدِيَّ، حَدَّثَهُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي جَارِيَتَانِ تُغَنِّيَانِ بِغِنَاءِ بُعَاثَ، فَاضْطَجَعَ عَلَى الْفِرَاشِ وَحَوَّلَ وَجْهَهُ، وَدَخَلَ أَبُو بَكْرٍ فَانْتَهَرَنِي وَقَالَ مِزْمَارَةُ الشَّيْطَانِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَقْبَلَ عَلَيْهِ رَسُولُ اللَّهِ ـ عَلَيْهِ السَّلاَمُ ـ فَقَالَ ‏"‏ دَعْهُمَا ‏"‏ فَلَمَّا غَفَلَ غَمَزْتُهُمَا فَخَرَجَتَا‏.‏ وَكَانَ يَوْمَ عِيدٍ يَلْعَبُ السُّودَانُ بِالدَّرَقِ وَالْحِرَابِ، فَإِمَّا سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم وَإِمَّا قَالَ ‏"‏ تَشْتَهِينَ تَنْظُرِينَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَأَقَامَنِي وَرَاءَهُ خَدِّي عَلَى خَدِّهِ، وَهُوَ يَقُولُ ‏"‏ دُونَكُمْ يَا بَنِي أَرْفِدَةَ ‏"‏‏.‏ حَتَّى إِذَا مَلِلْتُ قَالَ ‏"‏ حَسْبُكِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَاذْهَبِي ‏"‏‏.‏\hadithno{950}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) came to my house while two girls were singing beside me the songs of Buath (a story about the war between the two tribes of the Ansar, the Khazraj and the Aus, before Islam). The Prophet (ﷺ) lay down and turned his face to the other side. Then Abu Bakr came and spoke to me harshly saying, "Musical instruments of Satan near the Prophet (ﷺ) ?" Allah's Messenger (ﷺ) turned his face towards him and said, "Leave them." When Abu Bakr became inattentive, I signaled to those girls to go out and they left. It was the day of `Id, and the Black people were playing with shields and spears; so either I requested the Prophet (ﷺ) or he asked me whether I would like to see the display. I replied in the affirmative. Then the Prophet (ﷺ) made me stand behind him and my cheek was touching his cheek and he was saying, "Carry on! O Bani Arfida," till I got tired. The Prophet (ﷺ) asked me, "Are you satisfied (Is that sufficient for you)?" I replied in the affirmative and he told me to leave}}
\hadithdefcmd{bukhari}{951}{حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي زُبَيْدٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، عَنِ الْبَرَاءِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ فَقَالَ ‏ "‏ إِنَّ أَوَّلَ مَا نَبْدَأُ مِنْ يَوْمِنَا هَذَا أَنْ نُصَلِّيَ، ثُمَّ نَرْجِعَ فَنَنْحَرَ، فَمَنْ فَعَلَ فَقَدْ أَصَابَ سُنَّتَنَا ‏"‏‏.‏\hadithno{951}\hadithtrans{Narrated Al-Bara':I heard the Prophet (ﷺ) delivering a Khutba saying, "The first thing to be done on this day (first day of `Id ul Adha) is to pray; and after returning from the prayer we slaughter our sacrifices (in the name of Allah) and whoever does so, he acted according to our Sunna (traditions)}}
\hadithdefcmd{bukhari}{952}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ أَبُو بَكْرٍ وَعِنْدِي جَارِيَتَانِ مِنْ جَوَارِي الأَنْصَارِ تُغَنِّيَانِ بِمَا تَقَاوَلَتِ الأَنْصَارُ يَوْمَ بُعَاثَ ـ قَالَتْ وَلَيْسَتَا بِمُغَنِّيَتَيْنِ ـ فَقَالَ أَبُو بَكْرٍ أَمَزَامِيرُ الشَّيْطَانِ فِي بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَلِكَ فِي يَوْمِ عِيدٍ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا بَكْرٍ إِنَّ لِكُلِّ قَوْمٍ عِيدًا، وَهَذَا عِيدُنَا ‏"‏‏.‏\hadithno{952}\hadithtrans{Narrated Aisha:Abu Bakr came to my house while two small Ansari girls were singing beside me the stories of the Ansar concerning the Day of Buath. And they were not singers. Abu Bakr said protestingly, "Musical instruments of Satan in the house of Allah's Messenger (ﷺ) !" It happened on the `Id day and Allah's Messenger (ﷺ) said, "O Abu Bakr! There is an `Id for every nation and this is our `Id}}
\hadithdefcmd{bukhari}{953}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَغْدُو يَوْمَ الْفِطْرِ حَتَّى يَأْكُلَ تَمَرَاتٍ‏.‏ وَقَالَ مُرَجَّى بْنُ رَجَاءٍ حَدَّثَنِي عُبَيْدُ اللَّهِ قَالَ حَدَّثَنِي أَنَسٌ عَنِ النَّبِيِّ صلى الله عليه وسلم وَيَأْكُلُهُنَّ وِتْرًا‏.‏\hadithno{953}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) never proceeded (for the prayer) on the Day of `Id-ul-Fitr unless he had eaten some dates. Anas also narrated: The Prophet (ﷺ) used to eat odd number of dates}}
\hadithdefcmd{bukhari}{954}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيُعِدْ ‏"‏‏.‏ فَقَامَ رَجُلٌ فَقَالَ هَذَا يَوْمٌ يُشْتَهَى فِيهِ اللَّحْمُ‏.‏ وَذَكَرَ مِنْ جِيرَانِهِ فَكَأَنَّ النَّبِيَّ صلى الله عليه وسلم صَدَّقَهُ، قَالَ وَعِنْدِي جَذَعَةٌ أَحَبُّ إِلَىَّ مِنْ شَاتَىْ لَحْمٍ، فَرَخَّصَ لَهُ النَّبِيُّ صلى الله عليه وسلم فَلاَ أَدْرِي أَبَلَغَتِ الرُّخْصَةُ مَنْ سِوَاهُ أَمْ لاَ‏.‏\hadithno{954}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Whoever slaughtered (his sacrifice) before the `Id prayer, should slaughter again." A man stood up and said, "This is the day on which one has desire for meat," and he mentioned something about his neighbors. It seemed that the Prophet (ﷺ) believed him. Then the same man added, "I have a young she-goat which is dearer to me than the meat of two sheep." The Prophet (ﷺ) permitted him to slaughter it as a sacrifice. I do not know whether that permission was valid only for him or for others as well}}
\hadithdefcmd{bukhari}{955}{حَدَّثَنَا عُثْمَانُ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ خَطَبَنَا النَّبِيُّ صلى الله عليه وسلم يَوْمَ الأَضْحَى بَعْدَ الصَّلاَةِ فَقَالَ ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَنَسَكَ نُسُكَنَا فَقَدْ أَصَابَ النُّسُكَ، وَمَنْ نَسَكَ قَبْلَ الصَّلاَةِ فَإِنَّهُ قَبْلَ الصَّلاَةِ، وَلاَ نُسُكَ لَهُ ‏"‏‏.‏ فَقَالَ أَبُو بُرْدَةَ بْنُ نِيَارٍ خَالُ الْبَرَاءِ يَا رَسُولَ اللَّهِ، فَإِنِّي نَسَكْتُ شَاتِي قَبْلَ الصَّلاَةِ، وَعَرَفْتُ أَنَّ الْيَوْمَ يَوْمُ أَكْلٍ وَشُرْبٍ، وَأَحْبَبْتُ أَنْ تَكُونَ شَاتِي أَوَّلَ مَا يُذْبَحُ فِي بَيْتِي، فَذَبَحْتُ شَاتِي وَتَغَدَّيْتُ قَبْلَ أَنْ آتِيَ الصَّلاَةَ‏.‏ قَالَ ‏"‏ شَاتُكَ شَاةُ لَحْمٍ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، فَإِنَّ عِنْدَنَا عَنَاقًا لَنَا جَذَعَةً هِيَ أَحَبُّ إِلَىَّ مِنْ شَاتَيْنِ، أَفَتَجْزِي عَنِّي قَالَ ‏"‏ نَعَمْ، وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏\hadithno{955}\hadithtrans{Narrated Al-Bara' bin `Azib:The Prophet (ﷺ) delivered the Khutba after offering the prayer on the Day of Nahr and said, "Whoever offers the prayer like us and slaughters like us then his Nusuk (sacrifice) will be accepted by Allah. And whoever slaughters his sacrifice before the `Id prayer then he has not done the sacrifice." Abi Burda bin Niyar, the uncle of Al-Bara' said, "O Allah's Messenger (ﷺ)! I have slaughtered my sheep before the `Id prayer and I thought today as a day of eating and drinking (not alcoholic drinks), and I liked that my sheep should be the first to be slaughtered in my house. So I slaughtered my sheep and took my food before coming for the prayer." The Prophet (ﷺ) said, "The sheep which you have slaughtered is just mutton (not a Nusuk)." He (Abu Burda) said, "O Allah's Messenger (ﷺ)! I have a young she-goat which is dearer to me than two sheep. Will that be sufficient as a Nusuk on my behalf? "The Prophet (ﷺ) said, "Yes, it will be sufficient for you but it will not be sufficient (as a Nusuk) for anyone else after you}}
\hadithdefcmd{bukhari}{956}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدٌ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْرُجُ يَوْمَ الْفِطْرِ وَالأَضْحَى إِلَى الْمُصَلَّى، فَأَوَّلُ شَىْءٍ يَبْدَأُ بِهِ الصَّلاَةُ ثُمَّ يَنْصَرِفُ، فَيَقُومُ مُقَابِلَ النَّاسِ، وَالنَّاسُ جُلُوسٌ عَلَى صُفُوفِهِمْ، فَيَعِظُهُمْ وَيُوصِيهِمْ وَيَأْمُرُهُمْ، فَإِنْ كَانَ يُرِيدُ أَنْ يَقْطَعَ بَعْثًا قَطَعَهُ، أَوْ يَأْمُرَ بِشَىْءٍ أَمَرَ بِهِ، ثُمَّ يَنْصَرِفُ‏.‏ قَالَ أَبُو سَعِيدٍ فَلَمْ يَزَلِ النَّاسُ عَلَى ذَلِكَ حَتَّى خَرَجْتُ مَعَ مَرْوَانَ وَهْوَ أَمِيرُ الْمَدِينَةِ فِي أَضْحًى أَوْ فِطْرٍ، فَلَمَّا أَتَيْنَا الْمُصَلَّى إِذَا مِنْبَرٌ بَنَاهُ كَثِيرُ بْنُ الصَّلْتِ، فَإِذَا مَرْوَانُ يُرِيدُ أَنْ يَرْتَقِيَهُ قَبْلَ أَنْ يُصَلِّيَ، فَجَبَذْتُ بِثَوْبِهِ فَجَبَذَنِي فَارْتَفَعَ، فَخَطَبَ قَبْلَ الصَّلاَةِ، فَقُلْتُ لَهُ غَيَّرْتُمْ وَاللَّهِ‏.‏ فَقَالَ أَبَا سَعِيدٍ، قَدْ ذَهَبَ مَا تَعْلَمُ‏.‏ فَقُلْتُ مَا أَعْلَمُ وَاللَّهِ خَيْرٌ مِمَّا لاَ أَعْلَمُ‏.‏ فَقَالَ إِنَّ النَّاسَ لَمْ يَكُونُوا يَجْلِسُونَ لَنَا بَعْدَ الصَّلاَةِ فَجَعَلْتُهَا قَبْلَ الصَّلاَةِ‏.‏\hadithno{956}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) used to proceed to the Musalla on the days of Id-ul-Fitr and Id-ul-Adha; the first thing to begin with was the prayer and after that he would stand in front of the people and the people would keep sitting in their rows. Then he would preach to them, advise them and give them orders, (i.e. Khutba). And after that if he wished to send an army for an expedition, he would do so; or if he wanted to give an order, he would do so, and then depart. The people followed this tradition till I went out with Marwan, the Governor of Medina, for the prayer of Id-ul-Adha or Id-ul-Fitr. When we reached the Musalla, there was a pulpit made by Kathir bin As-Salt. Marwan wanted to get up on that pulpit before the prayer. I got hold of his clothes but he pulled them and ascended the pulpit and delivered the Khutba before the prayer. I said to him, "By Allah, you have changed (the Prophet's tradition)." He replied, "O Abu Sa`id! Gone is that which you know." I said, "By Allah! What I know is better than what I do not know." Marwan said, "People do not sit to listen to our Khutba after the prayer, so I delivered the Khutba before the prayer}}
\hadithdefcmd{bukhari}{957}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا أَنَسٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ،‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي فِي الأَضْحَى وَالْفِطْرِ، ثُمَّ يَخْطُبُ بَعْدَ الصَّلاَةِ‏.‏\hadithno{957}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) used to offer the prayer of `Id-ul-Adha and `Id-ul-Fitr and then deliver the Khutba after the prayer}}
\hadithdefcmd{bukhari}{961}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْفِطْرِ، فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ‏.‏ قَالَ وَأَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ عَبَّاسٍ، أَرْسَلَ إِلَى ابْنِ الزُّبَيْرِ فِي أَوَّلِ مَا بُويِعَ لَهُ إِنَّهُ لَمْ يَكُنْ يُؤَذَّنُ بِالصَّلاَةِ يَوْمَ الْفِطْرِ، إِنَّمَا الْخُطْبَةُ بَعْدَ الصَّلاَةِ‏.‏ وَأَخْبَرَنِي عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالاَ لَمْ يَكُنْ يُؤَذَّنُ يَوْمَ الْفِطْرِ وَلاَ يَوْمَ الأَضْحَى‏.‏ وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ فَبَدَأَ بِالصَّلاَةِ، ثُمَّ خَطَبَ النَّاسَ بَعْدُ، فَلَّمَا فَرَغَ نَبِيُّ اللَّهِ صلى الله عليه وسلم نَزَلَ فَأَتَى النِّسَاءَ، فَذَكَّرَهُنَّ وَهْوَ يَتَوَكَّأُ عَلَى يَدِ بِلاَلٍ، وَبِلاَلٌ بَاسِطٌ ثَوْبَهُ، يُلْقِي فِيهِ النِّسَاءُ صَدَقَةً‏.‏ قُلْتُ لِعَطَاءٍ أَتَرَى حَقًّا عَلَى الإِمَامِ الآنَ أَنْ يَأْتِيَ النِّسَاءَ فَيُذَكِّرَهُنَّ حِينَ يَفْرُغُ قَالَ إِنَّ ذَلِكَ لَحَقٌّ عَلَيْهِمْ، وَمَا لَهُمْ أَنْ لاَ يَفْعَلُوا\hadithno{961}\hadithtrans{Narrated Ibn Juraij:`Ata' said, "Jabir bin `Abdullah said, 'The Prophet (ﷺ) went out on the Day of `Id-ul-Fitr and offered the prayer before delivering the Khutba, Ata told me that during the early days of Ibn Az-Zubair, Ibn `Abbas had sent a message to him telling him that the Adhan for the `Id Prayer was never pronounced (in the life time of Allah's Messenger (ﷺ)) and the Khutba used to be delivered after the prayer. Ata told me that Ibn `Abbas and Jabir bin `Abdullah, had said, "There was no Adhan for the prayer of `Id-ul-Fitr and `Id-ul-Aqha." `Ata' said, "I heard Jabir bin `Abdullah saying, 'The Prophet (ﷺ) stood up and started with the prayer, and after it he delivered the Khutba. When the Prophet of Allah (ﷺ) finished (the Khutba), he went to the women and preached to them, while he was leaning on Bilal's hand. Bilal was spreading his garment and the ladies were putting alms in it.' " I said to Ata, "Do you think it incumbent upon an Imam to go to the women and preach to them after finishing the prayer and Khutba?" `Ata' said, "No doubt it is incumbent on Imams to do so, and why should they not do so?}}
\hadithdefcmd{bukhari}{962}{حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ شَهِدْتُ الْعِيدَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ ـ رضى الله عنهم ـ فَكُلُّهُمْ كَانُوا يُصَلُّونَ قَبْلَ الْخُطْبَةِ‏.‏\hadithno{962}\hadithtrans{Narrated Ibn `Abbas:I offered the `Id prayer with Allah's Messenger (ﷺ), Abu Bakr, `Umar and `Uthman and all of them offered the prayer before delivering the Khutba}}
\hadithdefcmd{bukhari}{963}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ ـ رضى الله عنهما ـ يُصَلُّونَ الْعِيدَيْنِ قَبْلَ الْخُطْبَةِ‏.‏\hadithno{963}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ), Abu Bakr and `Umar! used to offer the two `Id prayers before delivering the Khutba}}
\hadithdefcmd{bukhari}{964}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى يَوْمَ الْفِطْرِ رَكْعَتَيْنِ، لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا، ثُمَّ أَتَى النِّسَاءَ وَمَعَهُ بِلاَلٌ، فَأَمَرَهُنَّ بِالصَّدَقَةِ، فَجَعَلْنَ يُلْقِينَ، تُلْقِي الْمَرْأَةُ خُرْصَهَا وَسِخَابَهَا‏.‏\hadithno{964}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) offered a two rak`at prayer on the Day of Id ul Fitr and he did not pray before or after it. Then he went towards women along with Bilal and ordered them to pay alms and so they started giving their earrings and necklaces (in charity)}}
\hadithdefcmd{bukhari}{965}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا زُبَيْدٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ أَوَّلَ مَا نَبْدَأُ فِي يَوْمِنَا هَذَا أَنْ نُصَلِّيَ، ثُمَّ نَرْجِعَ فَنَنْحَرَ، فَمَنْ فَعَلَ ذَلِكَ فَقَدْ أَصَابَ سُنَّتَنَا، وَمَنْ نَحَرَ قَبْلَ الصَّلاَةِ فَإِنَّمَا هُوَ لَحْمٌ قَدَّمَهُ لأَهْلِهِ، لَيْسَ مِنَ النُّسْكِ فِي شَىْءٍ ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ يُقَالُ لَهُ أَبُو بُرْدَةَ بْنُ نِيَارٍ يَا رَسُولَ اللَّهِ، ذَبَحْتُ وَعِنْدِي جَذَعَةٌ خَيْرٌ مِنْ مُسِنَّةٍ‏.‏ فَقَالَ ‏"‏ اجْعَلْهُ مَكَانَهُ، وَلَنْ تُوفِيَ أَوْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏\hadithno{965}\hadithtrans{Narrated Al-Bara' bin `Azib:The Prophet (ﷺ) said, "The first thing that we should do on this day of ours is to pray and then return to slaughter the sacrifice. So anyone who does so, he acted according to our Sunna (tradition), and whoever slaughtered the sacrifice before the prayer, it was just meat which he presented to his family and would not be considered as Nusuk." A person from the Ansar named Abu Burda bin Niyar said, "O Allah's Messenger (ﷺ)! I slaughtered the Nusuk (before the prayer) but I have a young shegoat which is better than an older sheep." The Prophet (ﷺ) said, "Sacrifice it in lieu of the first, but it will not be sufficient (as a sacrifice) for anybody else after you}}
\hadithdefcmd{bukhari}{966}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى أَبُو السُّكَيْنِ، قَالَ حَدَّثَنَا الْمُحَارِبِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سُوقَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كُنْتُ مَعَ ابْنِ عُمَرَ حِينَ أَصَابَهُ سِنَانُ الرُّمْحِ فِي أَخْمَصِ قَدَمِهِ، فَلَزِقَتْ قَدَمُهُ بِالرِّكَابِ، فَنَزَلْتُ فَنَزَعْتُهَا وَذَلِكَ بِمِنًى، فَبَلَغَ الْحَجَّاجَ فَجَعَلَ يَعُودُهُ فَقَالَ الْحَجَّاجُ لَوْ نَعْلَمُ مَنْ أَصَابَكَ‏.‏ فَقَالَ ابْنُ عُمَرَ أَنْتَ أَصَبْتَنِي‏.‏ قَالَ وَكَيْفَ قَالَ حَمَلْتَ السِّلاَحَ فِي يَوْمٍ لَمْ يَكُنْ يُحْمَلُ فِيهِ، وَأَدْخَلْتَ السِّلاَحَ الْحَرَمَ وَلَمْ يَكُنِ السِّلاَحُ يُدْخَلُ الْحَرَمَ‏.‏\hadithno{966}\hadithtrans{Narrated Sa`id bin Jubair:I was with Ibn `Umar when a spear head pierced the sole of his foot and his foot stuck to the paddle of the saddle and I got down and pulled his foot out, and that happened in Mina. Al-Hajjaj got the news and came to inquire about his health and said, "Alas! If we could only know the man who wounded you!" Ibn `Umar said, "You are the one who wounded me." Al-Hajjaj said, "How is that?" Ibn `Umar said, "You have allowed the arms to be carried on a day on which nobody used to carry them and you allowed arms to be carried in the Haram even though it was not allowed before}}
\hadithdefcmd{bukhari}{967}{حَدَّثَنَا أَحْمَدُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ سَعِيدِ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ، عَنْ أَبِيهِ، قَالَ دَخَلَ الْحَجَّاجُ عَلَى ابْنِ عُمَرَ وَأَنَا عِنْدَهُ، فَقَالَ كَيْفَ هُوَ فَقَالَ صَالِحٌ‏.‏ فَقَالَ مَنْ أَصَابَكَ قَالَ أَصَابَنِي مَنْ أَمَرَ بِحَمْلِ السِّلاَحِ فِي يَوْمٍ لاَ يَحِلُّ فِيهِ حَمْلُهُ، يَعْنِي الْحَجَّاجَ‏.‏\hadithno{967}\hadithtrans{Narrated Sa`id bin `Amr bin Sa`id bin Al-`Aas:Al-Hajjaj went to Ibn `Umar while I was present there. Al-Hajjaj asked Ibn `Umar, "How are you?" Ibn `Umar replied, "I am all right," Al-Hajjaj asked, "Who wounded you?" Ibn `Umar replied, "The person who allowed arms to be carried on the day on which it was forbidden to carry them (he meant Al-Hajjaj)}}
\hadithdefcmd{bukhari}{968}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، قَالَ خَطَبَنَا النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ قَالَ ‏"‏ إِنَّ أَوَّلَ مَا نَبْدَأُ بِهِ فِي يَوْمِنَا هَذَا أَنْ نُصَلِّيَ ثُمَّ نَرْجِعَ فَنَنْحَرَ، فَمَنْ فَعَلَ ذَلِكَ فَقَدْ أَصَابَ سُنَّتَنَا، وَمَنْ ذَبَحَ قَبْلَ أَنْ يُصَلِّيَ فَإِنَّمَا هُوَ لَحْمٌ عَجَّلَهُ لأَهْلِهِ، لَيْسَ مِنَ النُّسُكِ فِي شَىْءٍ ‏"‏‏.‏ فَقَامَ خَالِي أَبُو بُرْدَةَ بْنُ نِيَارٍ فَقَالَ يَا رَسُولَ اللَّهِ، أَنَا ذَبَحْتُ قَبْلَ أَنْ أُصَلِّيَ وَعِنْدِي جَذَعَةٌ خَيْرٌ مِنْ مُسِنَّةٍ‏.‏ قَالَ ‏"‏ اجْعَلْهَا مَكَانَهَا ـ أَوْ قَالَ اذْبَحْهَا ـ وَلَنْ تَجْزِيَ جَذَعَةٌ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏\hadithno{968}\hadithtrans{Narrated Al-Bara':The Prophet (ﷺ) delivered the Khutba on the day of Nahr (`Id-ul-Adha) and said, "The first thing we should do on this day of ours is to pray and then return and slaughter (our sacrifices). So anyone who does so he acted according to our Sunna; and whoever slaughtered before the prayer then it was just meat that he offered to his family and would not be considered as a sacrifice in any way. My uncle Abu Burda bin Niyar got up and said, "O Allah's Messenger (ﷺ)! I slaughtered the sacrifice before the prayer but I have a young she-goat which is better than an older sheep." The Prophet (ﷺ) said, "Slaughter it in lieu of the first and such a goat will not be considered as a sacrifice for anybody else after you}}
\hadithdefcmd{bukhari}{969}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَا الْعَمَلُ فِي أَيَّامِ الْعَشْرِ أَفْضَلَ مِنَ الْعَمَلِ فِي هَذِهِ ‏"‏‏.‏ قَالُوا وَلاَ الْجِهَادُ قَالَ ‏"‏ وَلاَ الْجِهَادُ، إِلاَّ رَجُلٌ خَرَجَ يُخَاطِرُ بِنَفْسِهِ وَمَالِهِ فَلَمْ يَرْجِعْ بِشَىْءٍ ‏"‏‏.‏\hadithno{969}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "No good deeds done on other days are superior to those done on these (first ten days of Dhul Hijja)." Then some companions of the Prophet (ﷺ) said, "Not even Jihad?" He replied, "Not even Jihad, except that of a man who does it by putting himself and his property in danger (for Allah's sake) and does not return with any of those things}}
\hadithdefcmd{bukhari}{970}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ الثَّقَفِيُّ، قَالَ سَأَلْتُ أَنَسًا وَنَحْنُ غَادِيَانِ مِنْ مِنًى إِلَى عَرَفَاتٍ عَنِ التَّلْبِيَةِ كَيْفَ كُنْتُمْ تَصْنَعُونَ مَعَ النَّبِيِّ صلى الله عليه وسلم قَالَ كَانَ يُلَبِّي الْمُلَبِّي لاَ يُنْكَرُ عَلَيْهِ، وَيُكَبِّرُ الْمُكَبِّرُ فَلاَ يُنْكَرُ عَلَيْهِ‏.‏\hadithno{970}\hadithtrans{Narrated Muhammad bin Abi Bakr Al-Thaqafi:While we were going from Mina to `Arafat, I asked Anas bin Malik, about Talbiya, "How did you use to say Talbiya in the company of the Prophet?" Anas said: "People used to say Talbiya and their saying was not objected to and they used to say Takbir and that was not objected to either}}
\hadithdefcmd{bukhari}{971}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ عَاصِمٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ كُنَّا نُؤْمَرُ أَنْ نَخْرُجَ يَوْمَ الْعِيدِ، حَتَّى نُخْرِجَ الْبِكْرَ مِنْ خِدْرِهَا، حَتَّى نُخْرِجَ الْحُيَّضَ فَيَكُنَّ خَلْفَ النَّاسِ، فَيُكَبِّرْنَ بِتَكْبِيرِهِمْ، وَيَدْعُونَ بِدُعَائِهِمْ يَرْجُونَ بَرَكَةَ ذَلِكَ الْيَوْمِ وَطُهْرَتَهُ‏.‏\hadithno{971}\hadithtrans{Narrated Um `Atiya:We used to be ordered to come out on the Day of `Id and even bring out the virgin girls from their houses and menstruating women so that they might stand behind the men and say Takbir along with them and invoke Allah along with them and hope for the blessings of that day and for purification from sins}}
\hadithdefcmd{bukhari}{972}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ تُرْكَزُ الْحَرْبَةُ قُدَّامَهُ يَوْمَ الْفِطْرِ وَالنَّحْرِ ثُمَّ يُصَلِّي‏.‏\hadithno{972}\hadithtrans{Narrated Ibn `Umar: On the day of `Id-ul-Fitr and `Id-ul-Adha a spear used to be planted in front of the Prophet (as a Sutra for the prayer) and then he would pray}}
\hadithdefcmd{bukhari}{973}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَغْدُو إِلَى الْمُصَلَّى، وَالْعَنَزَةُ بَيْنَ يَدَيْهِ، تُحْمَلُ وَتُنْصَبُ بِالْمُصَلَّى بَيْنَ يَدَيْهِ فَيُصَلِّي إِلَيْهَا‏.‏\hadithno{973}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to proceed to the Musalla and an 'Anaza used to be carried before him and planted in the Musalla in front of him and he would pray facing it (as a Sutra)}}
\hadithdefcmd{bukhari}{974}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أُمِرْنَا أَنْ نُخْرِجَ، الْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ‏.‏ وَعَنْ أَيُّوبَ عَنْ حَفْصَةَ بِنَحْوِهِ‏.‏ وَزَادَ فِي حَدِيثِ حَفْصَةَ قَالَ أَوْ قَالَتِ الْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ، وَيَعْتَزِلْنَ الْحُيَّضُ الْمُصَلَّى‏.‏\hadithno{974}\hadithtrans{Narrated Muhammad:Um 'Atiyya said: "Our Prophet ordered us to come out (on `Id day) with the mature girls and the virgins staying in seclusion." Hafsa narrated the above mentioned Hadith and added, "The mature girls or virgins staying in seclusion but the menstruating women had to keep away from the Musalla}}
\hadithdefcmd{bukhari}{975}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ خَرَجْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ فِطْرٍ أَوْ أَضْحَى، فَصَلَّى ثُمَّ خَطَبَ، ثُمَّ أَتَى النِّسَاءَ فَوَعَظَهُنَّ وَذَكَّرَهُنَّ، وَأَمَرَهُنَّ بِالصَّدَقَةِ‏.‏\hadithno{975}\hadithtrans{Narrated Ibn `Abbas:I (in my boyhood) went out with the Prophet (ﷺ) on the day of `Id ul Fitr or Id-ul-Adha. The Prophet (ﷺ) prayed and then delivered the Khutba and then went towards the women, preached and advised them and ordered them to give alms}}
\hadithdefcmd{bukhari}{976}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ زُبَيْدٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ أَضْحًى إِلَى الْبَقِيعِ فَصَلَّى رَكْعَتَيْنِ، ثُمَّ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ وَقَالَ ‏"‏ إِنَّ أَوَّلَ نُسُكِنَا فِي يَوْمِنَا هَذَا أَنْ نَبْدَأَ بِالصَّلاَةِ، ثُمَّ نَرْجِعَ فَنَنْحَرَ، فَمَنْ فَعَلَ ذَلِكَ فَقَدْ وَافَقَ سُنَّتَنَا، وَمَنْ ذَبَحَ قَبْلَ ذَلِكَ فَإِنَّمَا هُوَ شَىْءٌ عَجَّلَهُ لأَهْلِهِ، لَيْسَ مِنَ النُّسُكِ فِي شَىْءٍ ‏"‏‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ، إِنِّي ذَبَحْتُ وَعِنْدِي جَذَعَةٌ خَيْرٌ مِنْ مُسِنَّةٍ‏.‏ قَالَ ‏"‏ اذْبَحْهَا، وَلاَ تَفِي عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏\hadithno{976}\hadithtrans{Narrated Al-Bara':The Prophet (ﷺ) went towards Al-Baqi (the graveyard at Medina) on the day of Id-ul-Adha and offered a two-rak`at prayer (of `Id-ul-Adha) and then faced us and said, "On this day of ours, our first act of worship is the offering of prayer and then we will return and slaughter the sacrifice, and whoever does this concords with our Sunna; and whoever slaughtered his sacrifice before that (i.e. before the prayer) then that was a thing which he prepared earlier for his family and it would not be considered as a Nusuk (sacrifice.)" A man stood up and said, "O, Allah's Messenger (ﷺ)! I slaughtered (the animal before the prayer) but I have a young she-goat which is better than an older sheep." The Prophet (ﷺ) said to him, "Slaughter it. But a similar sacrifice will not be sufficient for anybody else after you}}
\hadithdefcmd{bukhari}{977}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَابِسٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قِيلَ لَهُ أَشَهِدْتَ الْعِيدَ مَعَ النَّبِيِّ صلى الله عليه وسلم قَالَ نَعَمْ، وَلَوْلاَ مَكَانِي مِنَ الصِّغَرِ مَا شَهِدْتُهُ، حَتَّى أَتَى الْعَلَمَ الَّذِي عِنْدَ دَارِ كَثِيرِ بْنِ الصَّلْتِ فَصَلَّى ثُمَّ خَطَبَ ثُمَّ أَتَى النِّسَاءَ، وَمَعَهُ بِلاَلٌ، فَوَعَظَهُنَّ وَذَكَّرَهُنَّ، وَأَمَرَهُنَّ بِالصَّدَقَةِ، فَرَأَيْتُهُنَّ يُهْوِينَ بِأَيْدِيهِنَّ يَقْذِفْنَهُ فِي ثَوْبِ بِلاَلٍ، ثُمَّ انْطَلَقَ هُوَ وَبِلاَلٌ إِلَى بَيْتِهِ‏.‏\hadithno{977}\hadithtrans{Narrated `Abdur Rahman bin `Abis:Ibn `Abbas was asked whether he had joined the Prophet (ﷺ) in the `Id prayer. He said, "Yes. And I could not have joined him had I not been young. (The Prophet (ﷺ) came out) till he reached the mark which was near the house of Kathir bin As-Salt, offered the prayer, delivered the Khutba and then went towards the women. Bilal was accompanying him. He preached to them and advised them and ordered them to give alms. I saw the women putting their ornaments with their outstretched hands into Bilal's garment. Then the Prophet (ﷺ) along with Bilal returned home}}
\hadithdefcmd{bukhari}{978}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ الْفِطْرِ، فَصَلَّى فَبَدَأَ بِالصَّلاَةِ ثُمَّ خَطَبَ، فَلَمَّا فَرَغَ نَزَلَ فَأَتَى النِّسَاءَ، فَذَكَّرَهُنَّ وَهْوَ يَتَوَكَّأُ عَلَى يَدِ بِلاَلٍ وَبِلاَلٌ بَاسِطٌ ثَوْبَهُ، يُلْقِي فِيهِ النِّسَاءُ الصَّدَقَةَ‏.‏ قُلْتُ لِعَطَاءٍ زَكَاةَ يَوْمِ الْفِطْرِ قَالَ لاَ وَلَكِنْ صَدَقَةً يَتَصَدَّقْنَ حِينَئِذٍ، تُلْقِي فَتَخَهَا وَيُلْقِينَ‏.‏ قُلْتُ أَتُرَى حَقًّا عَلَى الإِمَامِ ذَلِكَ وَيُذَكِّرُهُنَّ قَالَ إِنَّهُ لَحَقٌّ عَلَيْهِمْ، وَمَا لَهُمْ لاَ يَفْعَلُونَهُ\hadithno{978}\hadithtrans{Narrated Ibn Juraij:`Ata' told me that he had heard Jabir bin `Abdullah saying, "The Prophet (ﷺ) stood up to offer the prayer of the `Id ul Fitr. He first offered the prayer and then delivered the Khutba. After finishing it he got down (from the pulpit) and went towards the women and advised them while he was leaning on Bilal's hand. Bilal was spreading out his garment where the women were putting their alms." I asked `Ata' whether it was the Zakat of `Id ul Fitr. He said, "No, it was just alms given at that time. Some lady put her finger ring and the others would do the same." I said, (to `Ata'), "Do you think that it is incumbent upon the Imam to give advice to the women (on `Id day)?" He said, "No doubt, it is incumbent upon the Imams to do so and why should they not do so?}}
\hadithdefcmd{bukhari}{979}{قَالَ ابْنُ جُرَيْجٍ وَأَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ شَهِدْتُ الْفِطْرَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ ـ رضى الله عنهم ـ يُصَلُّونَهَا قَبْلَ الْخُطْبَةِ، ثُمَّ يُخْطَبُ بَعْدُ، خَرَجَ النَّبِيُّ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَيْهِ حِينَ يُجْلِسُ بِيَدِهِ، ثُمَّ أَقْبَلَ يَشُقُّهُمْ حَتَّى جَاءَ النِّسَاءَ مَعَهُ بِلاَلٌ فَقَالَ ‏\{‏يَا أَيُّهَا النَّبِيُّ إِذَا جَاءَكَ الْمُؤْمِنَاتُ يُبَايِعْنَكَ‏\}‏ الآيَةَ ثُمَّ قَالَ حِينَ فَرَغَ مِنْهَا ‏"‏ آنْتُنَّ عَلَى ذَلِكَ ‏"‏‏.‏ قَالَتِ امْرَأَةٌ وَاحِدَةٌ مِنْهُنَّ لَمْ يُجِبْهُ غَيْرُهَا نَعَمْ‏.‏ لاَ يَدْرِي حَسَنٌ مَنْ هِيَ‏.‏ قَالَ ‏"‏ فَتَصَدَّقْنَ ‏"‏ فَبَسَطَ بِلاَلٌ ثَوْبَهُ ثُمَّ قَالَ هَلُمَّ لَكُنَّ فِدَاءٌ أَبِي وَأُمِّي، فَيُلْقِينَ الْفَتَخَ وَالْخَوَاتِيمَ فِي ثَوْبِ بِلاَلٍ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ الْفَتَخُ الْخَوَاتِيمُ الْعِظَامُ كَانَتْ فِي الْجَاهِلِيَّةِ‏.‏\hadithno{979}\hadithtrans{Al-Hasan bin Muslim told me that Ibn `Abbas had said, "I joined the Prophet, Abu Bakr, `Umar and `Uthman in the `Id ul Fitr prayers. They used to offer the prayer before the Khutba and then they used to deliver the Khutba afterwards. Once the Prophet (ﷺ) I came out (for the `Id prayer) as if I were just observing him waving to the people to sit down. He, then accompanied by Bilal, came crossing the rows till he reached the women. He recited the following verse:'O Prophet! When the believing women come to you to take the oath of fealty to you . . . (to the end of the verse) (60.12).' After finishing the recitation he said, "O ladies! Are you fulfilling your covenant?" None except one woman said, "Yes." Hasan did not know who was that woman. The Prophet (ﷺ) said, "Then give alms." Bilal spread his garment and said, "Keep on giving alms. Let my father and mother sacrifice their lives for you (ladies)." So the ladies kept on putting their Fatkhs (big rings) and other kinds of rings in Bilal's garment." `Abdur-Razaq said, " 'Fatkhs' is a big ring which used to be worn in the (Pre-Islamic) period of ignorance}}
\hadithdefcmd{bukhari}{980}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، قَالَتْ كُنَّا نَمْنَعُ جَوَارِيَنَا أَنْ يَخْرُجْنَ يَوْمَ الْعِيدِ، فَجَاءَتِ امْرَأَةٌ فَنَزَلَتْ قَصْرَ بَنِي خَلَفٍ فَأَتَيْتُهَا فَحَدَّثَتْ أَنَّ زَوْجَ أُخْتِهَا غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثِنْتَىْ عَشْرَةَ غَزْوَةً فَكَانَتْ أُخْتُهَا مَعَهُ فِي سِتِّ غَزَوَاتٍ‏.‏ فَقَالَتْ فَكُنَّا نَقُومُ عَلَى الْمَرْضَى وَنُدَاوِي الْكَلْمَى، فَقَالَتْ يَا رَسُولَ اللَّهِ، عَلَى إِحْدَانَا بَأْسٌ إِذَا لَمْ يَكُنْ لَهَا جِلْبَابٌ أَنْ لاَ تَخْرُجَ فَقَالَ ‏"‏ لِتُلْبِسْهَا صَاحِبَتُهَا مِنْ جِلْبَابِهَا فَلْيَشْهَدْنَ الْخَيْرَ وَدَعْوَةَ الْمُؤْمِنِينَ ‏"‏‏.‏ قَالَتْ حَفْصَةُ فَلَمَّا قَدِمَتْ أُمُّ عَطِيَّةَ أَتَيْتُهَا، فَسَأَلْتُهَا أَسَمِعْتِ فِي كَذَا وَكَذَا قَالَتْ نَعَمْ، بِأَبِي ـ وَقَلَّمَا ذَكَرَتِ النَّبِيَّ صلى الله عليه وسلم إِلاَّ قَالَتْ بِأَبِي ـ قَالَ ‏"‏ لِيَخْرُجِ الْعَوَاتِقُ ذَوَاتُ الْخُدُورِ ـ أَوْ قَالَ الْعَوَاتِقُ وَذَوَاتُ الْخُدُورِ شَكَّ أَيُّوبُ ـ وَالْحُيَّضُ، وَيَعْتَزِلُ الْحُيَّضُ الْمُصَلَّى، وَلْيَشْهَدْنَ الْخَيْرَ وَدَعْوَةَ الْمُؤْمِنِينَ ‏"‏‏.‏ قَالَتْ فَقُلْتُ لَهَا آلْحُيَّضُ قَالَتْ نَعَمْ، أَلَيْسَ الْحَائِضُ تَشْهَدُ عَرَفَاتٍ وَتَشْهَدُ كَذَا وَتَشْهَدُ كَذَا\hadithno{980}\hadithtrans{Narrated Aiyub:Hafsa bint Seereen said, "On Id we used to forbid our girls to go out for `Id prayer. A lady came and stayed at the palace of Bani Khalaf and I went to her. She said, 'The husband of my sister took part in twelve holy battles along with the Prophet (ﷺ) and my sister was with her husband in six of them. My sister said that they used to nurse the sick and treat the wounded. Once she asked, 'O Allah's Messenger (ﷺ)! If a woman has no veil, is there any harm if she does not come out (on `Id day)?' The Prophet (ﷺ) said, 'Her companion should let her share her veil with her, and the women should participate in the good deeds and in the religious gatherings of the believers.' " Hafsa added, "When Um-`Atiya came, I went to her and asked her, 'Did you hear anything about so-and-so?' Um-`Atiya said, 'Yes, let my father be sacrificed for the Prophet (ﷺ). (And whenever she mentioned the name of the Prophet (ﷺ) she always used to say, 'Let my father be sacrificed for him'). He said, 'Virgin mature girls staying often screened (or said, 'Mature girls and virgins staying often screened--Aiyub is not sure as which was right) and menstruating women should come out (on the `Id day). But the menstruating women should keep away from the Musalla. And all the women should participate in the good deeds and in the religious gatherings of the believers'." Hafsa said, "On that I said to Um-`Atiya, 'Also those who are menstruating?' " Um-`Atiya replied, "Yes. Do they not present themselves at `Arafat and elsewhere?}}
\hadithdefcmd{bukhari}{981}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، قَالَ قَالَتْ أُمُّ عَطِيَّةَ أُمِرْنَا أَنْ نَخْرُجَ فَنُخْرِجَ الْحُيَّضَ وَالْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ‏.‏ قَالَ ابْنُ عَوْنٍ أَوِ الْعَوَاتِقَ ذَوَاتِ الْخُدُورِ، فَأَمَّا الْحُيَّضُ فَيَشْهَدْنَ جَمَاعَةَ الْمُسْلِمِينَ وَدَعْوَتَهُمْ، وَيَعْتَزِلْنَ مُصَلاَّهُمْ‏.‏\hadithno{981}\hadithtrans{Narrated Um-`Atiya:We were ordered to go out (for `Id) and also to take along with us the menstruating women, mature girls and virgins staying in seclusion. (Ibn `Aun said, "Or mature virgins staying in seclusion)." The menstruating women could present themselves at the religious gathering and invocation of Muslims but should keep away from their Musalla}}
\hadithdefcmd{bukhari}{982}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي كَثِيرُ بْنُ فَرْقَدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَنْحَرُ أَوْ يَذْبَحُ بِالْمُصَلَّى‏.‏\hadithno{982}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to Nahr or slaughter sacrifices at the Musalla (on `Id-ul-Adha)}}
\hadithdefcmd{bukhari}{983}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ الْمُعْتَمِرِ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ بَعْدَ الصَّلاَةِ فَقَالَ ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَنَسَكَ نُسْكَنَا فَقَدْ أَصَابَ النُّسُكَ، وَمَنْ نَسَكَ قَبْلَ الصَّلاَةِ فَتِلْكَ شَاةُ لَحْمٍ ‏"‏‏.‏ فَقَامَ أَبُو بُرْدَةَ بْنُ نِيَارٍ فَقَالَ يَا رَسُولَ اللَّهِ وَاللَّهِ لَقَدْ نَسَكْتُ قَبْلَ أَنْ أَخْرُجَ إِلَى الصَّلاَةِ، وَعَرَفْتُ أَنَّ الْيَوْمَ يَوْمُ أَكْلٍ وَشُرْبٍ فَتَعَجَّلْتُ وَأَكَلْتُ وَأَطْعَمْتُ أَهْلِي وَجِيرَانِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ شَاةُ لَحْمٍ ‏"‏‏.‏ قَالَ فَإِنَّ عِنْدِي عَنَاقَ جَذَعَةٍ، هِيَ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ، فَهَلْ تَجْزِي عَنِّي قَالَ ‏"‏ نَعَمْ، وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏\hadithno{983}\hadithtrans{Narrated Al-Bara' bin `Azib:On the day of Nahr Allah's Messenger (ﷺ) delivered the Khutba after the `Id prayer and said, "Anyone who prayed like us and slaughtered the sacrifice like we did then he acted according to our (Nusuk) tradition of sacrificing, and whoever slaughtered the sacrifice before the prayer, then that was just mutton (i.e. not sacrifice)." Abu Burda bin Niyar stood up and said, "O Allah's Messenger (ﷺ)! By Allah, I slaughtered my sacrifice before I offered the (Id) prayer and thought that today was the day of eating and drinking (non-alcoholic drinks) and so I made haste (in slaughtering) and ate and also fed my family and neighbors." Allah's Messenger (ﷺ) said, "That was just mutton (not a sacrifice)." Then Abu Burda said, "I have a young she-goat and no doubt, it is better than two sheep. Will that be sufficient as a sacrifice for me?" The Prophet (ﷺ) replied, "Yes. But it will not be sufficient for anyone else (as a sacrifice), after you}}
\hadithdefcmd{bukhari}{984}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ، عَنْ حَمَّادِ بْنِ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، أَنَّ أَنَسَ بْنَ مَالِكٍ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى يَوْمَ النَّحْرِ، ثُمَّ خَطَبَ فَأَمَرَ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ أَنْ يُعِيدَ ذَبْحَهُ فَقَامَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ يَا رَسُولَ اللَّهِ، جِيرَانٌ لِي ـ إِمَّا قَالَ بِهِمْ خَصَاصَةٌ، وَإِمَّا قَالَ بِهِمْ فَقْرٌ ـ وَإِنِّي ذَبَحْتُ قَبْلَ الصَّلاَةِ وَعِنْدِي عَنَاقٌ لِي أَحَبُّ إِلَىَّ مِنْ شَاتَىْ لَحْمٍ‏.‏ فَرَخَّصَ لَهُ فِيهَا‏.‏\hadithno{984}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) offered the prayer on the day of Nahr and then delivered the Khutba and ordered that whoever had slaughtered his sacrifice before the prayer should repeat it, that is, should slaughter another sacrifice. Then a person from the Ansar stood up and said, "O Allah's Messenger (ﷺ)! because of my neighbors (he described them as being very needy or poor) I slaughtered before the prayer. I have a young she-goat which, in my opinion, is better than two sheep." The Prophet (ﷺ) gave him the permission for slaughtering it as a sacrifice}}
\hadithdefcmd{bukhari}{985}{حَدَّثَنَا مُسْلِمٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ، عَنْ جُنْدَبٍ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ ثُمَّ خَطَبَ، ثُمَّ ذَبَحَ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ أَنْ يُصَلِّيَ فَلْيَذْبَحْ أُخْرَى مَكَانَهَا، وَمَنْ لَمْ يَذْبَحْ فَلْيَذْبَحْ بِاسْمِ اللَّهِ ‏"‏‏.‏\hadithno{985}\hadithtrans{Narrated Jundab:On the day of Nahr the Prophet (ﷺ) offered the prayer and delivered the Khutba and then slaughtered the sacrifice and said, "Anybody who slaughtered (his sacrifice) before the prayer should slaughter another animal in lieu of it, and the one who has not yet slaughtered should slaughter the sacrifice mentioning Allah's name on it}}
\hadithdefcmd{bukhari}{986}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا أَبُو تُمَيْلَةَ، يَحْيَى بْنُ وَاضِحٍ عَنْ فُلَيْحِ بْنِ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا كَانَ يَوْمُ عِيدٍ خَالَفَ الطَّرِيقَ‏.‏ تَابَعَهُ يُونُسُ بْنُ مُحَمَّدٍ عَنْ فُلَيْحٍ‏.‏ وَحَدِيثُ جَابِرٍ أَصَحُّ‏.‏\hadithno{986}\hadithtrans{Narrated Jabir bin `Abdullah:On the Day of `Id the Prophet (ﷺ) used to return (after offering the `Id prayer) through a way different from that by which he went}}
\hadithdefcmd{bukhari}{988}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ فِي أَيَّامِ مِنًى تُدَفِّفَانِ وَتَضْرِبَانِ، وَالنَّبِيُّ صلى الله عليه وسلم مُتَغَشٍّ بِثَوْبِهِ، فَانْتَهَرَهُمَا أَبُو بَكْرٍ فَكَشَفَ النَّبِيُّ صلى الله عليه وسلم عَنْ وَجْهِهِ فَقَالَ ‏"‏ دَعْهُمَا يَا أَبَا بَكْرٍ فَإِنَّهَا أَيَّامُ عِيدٍ ‏"‏‏.‏ وَتِلْكَ الأَيَّامُ أَيَّامُ مِنًى‏.‏ وَقَالَتْ عَائِشَةُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتُرُنِي، وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ وَهُمْ يَلْعَبُونَ فِي الْمَسْجِدِ، فَزَجَرَهُمْ عُمَرُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعْهُمْ، أَمْنًا بَنِي أَرْفِدَةَ ‏"‏‏.‏ يَعْنِي مِنَ الأَمْنِ‏.‏\hadithno{988}\hadithtrans{Narrated `Urwa on the authority of `Aisha:On the days of Mina, (11th, 12th, and 13th of Dhul-Hijjah) Abu Bakr came to her while two young girls were beating the tambourine and the Prophet (ﷺ) was lying covered with his clothes. Abu Bakr scolded them and the Prophet (ﷺ) uncovered his face and said to Abu Bakr, "Leave them, for these days are the days of `Id and the days of Mina." `Aisha further said, "Once the Prophet (ﷺ) was screening me and I was watching the display of black slaves in the Mosque and (`Umar) scolded them. The Prophet (ﷺ) said, 'Leave them. O Bani Arfida! (carry on), you are safe (protected)}}
\hadithdefcmd{bukhari}{989}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَدِيُّ بْنُ ثَابِتٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْفِطْرِ، فَصَلَّى رَكْعَتَيْنِ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا وَمَعَهُ بِلاَلٌ‏.‏\hadithno{989}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) went out and offered a two rak`at prayer on the Day of `Id ul Fitr and did not offer any other prayer before or after it and at that time Bilal was accompanying him}}
